@@ -19,7 +19,7 @@ schema()
 	echo;
 }
 
-SCHEMES="pnm mms rtsp mmsh"
+SCHEMES="pnm mms net rtp rtsp mmsh uvox"
 
 echo "<gconfschemafile>";
 echo "    <schemalist>";
@@ -32,7 +32,7 @@ for i in $SCHEMES ; do
 	DEFAULT="totem \"%s\"";
 	schema;
 
-	KEY="need-terminal"
+	KEY="needs_terminal"
 	TYPE="bool";
 	DEFAULT="false";
 	schema;
