@@ -334,7 +334,7 @@ totem_sublang_equal_lists (GList *orig, GList *new)
 static void
 totem_languages_update (Totem *totem, GList *list)
 {
-	GtkWidget *item, *submenu;
+	GtkWidget *item, *submenu, *old_submenu;
 	GtkWidget *lang_menu;
 	int current;
 
@@ -348,6 +348,11 @@ totem_languages_update (Totem *totem, GList *list)
 
 	/* Languages */
 	item = glade_xml_get_widget (totem->xml, "tmw_languages_menu_item");
+
+	old_submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (item));
+	if (old_submenu != NULL)
+		gtk_menu_popdown (GTK_MENU (old_submenu));
+
 	submenu = glade_xml_get_widget (totem->xml, "tmw_menu_languages");
 	if (lang_menu == NULL)
 	{
@@ -365,7 +370,7 @@ totem_languages_update (Totem *totem, GList *list)
 static void
 totem_subtitles_update (Totem *totem, GList *list)
 {
-	GtkWidget *item, *submenu;
+	GtkWidget *item, *submenu, *old_submenu;
 	GtkWidget *sub_menu;
 	int current;
 
@@ -379,6 +384,11 @@ totem_subtitles_update (Totem *totem, GList *list)
 
 	/* Subtitles */
 	item = glade_xml_get_widget (totem->xml, "tmw_subtitles_menu_item");
+
+	old_submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (item));
+	if (old_submenu != NULL)
+		gtk_menu_popdown (GTK_MENU (old_submenu));
+
 	submenu = glade_xml_get_widget (totem->xml, "tmw_menu_subtitles");
 	if (sub_menu == NULL)
 	{
@@ -550,6 +560,20 @@ fake_gnome_vfs_device_get_something (GObject *device,
         }
 }
 
+static char *
+my_gnome_vfs_volume_get_mount_path (GnomeVFSVolume *volume)
+{
+	char *uri, *path;
+
+	uri = gnome_vfs_volume_get_activation_uri (volume);
+	path = g_filename_from_uri (uri, NULL, NULL);
+	g_free (uri);
+
+	if (path == NULL)
+		return gnome_vfs_volume_get_device_path (volume);
+	return path;
+}
+
 static void
 add_device_to_menu (GObject *device, GtkMenu *menu, gint position, Totem *totem)
 {
@@ -574,7 +598,7 @@ add_device_to_menu (GObject *device, GtkMenu *menu, gint position, Totem *totem)
 	icon_name = fake_gnome_vfs_device_get_something (device,
 		&gnome_vfs_volume_get_icon, &gnome_vfs_drive_get_icon);
 	device_path = fake_gnome_vfs_device_get_something (device,
-		&gnome_vfs_volume_get_device_path,
+		&my_gnome_vfs_volume_get_mount_path,
 		&gnome_vfs_drive_get_device_path);
 
 	label = g_strdup_printf (_("Play Disc '%s'"), name);
