@@ -38,6 +38,7 @@
 #include "bacon-volume.h"
 //FIXME damn build system!
 #include "totem-interface.c"
+#include "video-utils.h"
 
 GtkWidget *totem_volume_create (void);
 
@@ -272,7 +273,7 @@ on_about1_activate (GtkButton *button, TotemEmbedded *emb)
 
 	emb->about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
 			"name", _("Totem Mozilla Plugin"),
-			"version", VERSION,
+			"version", PACKAGE_VERSION,
 			"copyright", _("Copyright \xc2\xa9 2002-2005 Bastien Nocera"),
 			"comments", description,
 			"authors", authors,
@@ -322,24 +323,19 @@ on_play_pause (GtkWidget *widget, TotemEmbedded *emb)
 static void
 on_got_redirect (GtkWidget *bvw, const char *mrl, TotemEmbedded *emb)
 {
-	char *new_mrl;
+	gchar *new_filename;
 
 	g_message ("url: %s", emb->orig_filename);
 	g_message ("redirect: %s", mrl);
 
-	//FIXME write a proper one...
-	if (mrl[0] != '/' && strstr (mrl, "://") == NULL) {
-		char *dir;
-
-		dir = g_path_get_dirname (emb->orig_filename);
-		new_mrl = g_strdup_printf ("%s/%s", dir, mrl);
-		g_free (dir);
-	} else {
-		new_mrl = g_strdup (mrl);
-	}
+	if (emb->orig_filename)
+		new_filename = totem_resolve_relative_link (emb->orig_filename, mrl);
+	else
+		new_filename = totem_resolve_relative_link (emb->filename, mrl);
 
 	g_free (emb->filename);
-	emb->filename = new_mrl;
+	emb->filename = new_filename;
+
 	bacon_video_widget_close (emb->bvw);
 	totem_embedded_set_state (emb, STATE_STOPPED);
 
@@ -586,6 +582,10 @@ int main (int argc, char **argv)
 	gchar *svcname;
 	GError *e = NULL;
 
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
 	if (XInitThreads () == 0)
 	{
 		gtk_init (&argc, &argv);
